@@ -8,7 +8,7 @@ from infi.wioctl.errors import InvalidHandle
 from infi.pyutils.decorators import wraps
 from infi.exceptools import chain
 from infi.storagemodel.errors import DeviceDisappeared
-
+from infi.storagemodel.base.gevent_wrapper import defer
 from logging import getLogger
 logger = getLogger(__name__)
 
@@ -21,11 +21,12 @@ def replace_invalid_handle_with_device_disappeared(func):
             raise chain(DeviceDisappeared())
     return catcher
 
+
 class WindowsDeviceMixin(object):
     @cached_method
     def get_pdo(self):
         try:
-            return self._device_object.psuedo_device_object
+            return defer(getattr)(self._device_object, 'psuedo_device_object')
         except KeyError:
             logger.exception("Getting device pdo raised KeyError")
             raise DeviceDisappeared()
@@ -36,6 +37,7 @@ class WindowsDeviceMixin(object):
         from infi.asi import create_platform_command_executer
         handle = OSFile(self.get_pdo())
         executer = create_platform_command_executer(handle)
+        executer.call = defer(executer.call)
         try:
             yield executer
         finally:
@@ -55,17 +57,42 @@ class WindowsDeviceMixin(object):
     @replace_invalid_handle_with_device_disappeared
     def get_hctl(self):
         from infi.dtypes.hctl import HCTL
-        return HCTL(*self.get_ioctl_interface().scsi_get_address())
+        return HCTL(*defer(self.get_ioctl_interface().scsi_get_address)())
 
     @cached_method
     def get_parent(self):
         return self._device_object.parent
 
+    @cached_method
+    def _get_hwid(self):
+        hwid = defer(getattr)(self._device_object, 'hardware_ids')[0]
+        hwid = hwid.replace('SCSI\\Disk', '').replace('SCSI\\Array', '').replace('MPIO\\Disk', '')
+        return hwid
+
+    @cached_method
+    def get_scsi_vendor_id(self):
+        """Returns the stripped T10 vendor identifier string, as give in SCSI Standard Inquiry"""
+        hwid = self._get_hwid()
+        return hwid[:8].rstrip('_').replace('_', ' ')
+
+    @cached_method
+    def get_scsi_revision(self):
+        """Returns the stripped T10 revision string, as give in SCSI Standard Inquiry"""
+        hwid = self._get_hwid()
+        return hwid[24:].rstrip('_').replace('_', ' ')
+
+    @cached_method
+    def get_scsi_product_id(self):
+        """Returns the stripped T10 product identifier string, as give in SCSI Standard Inquiry"""
+        hwid = self._get_hwid()
+        return hwid[8:24].rstrip('_').replace('_', ' ')
+
+
 class WindowsDiskDeviceMixin(object):
     @cached_method
     @replace_invalid_handle_with_device_disappeared
     def get_size_in_bytes(self):
-        return self.get_ioctl_interface().disk_get_drive_geometry_ex()
+        return defer(self.get_ioctl_interface().disk_get_drive_geometry_ex)()
 
     @cached_method
     def get_physical_drive_number(self):
@@ -73,7 +100,7 @@ class WindowsDiskDeviceMixin(object):
         if the disk is hidden (i.e. part of MPIODisk), it returns -1
         """
         try:
-            number = self.get_ioctl_interface().storage_get_device_number()
+            number = defer(self.get_ioctl_interface().storage_get_device_number)()
             return -1 if number == 0xffffffff else number
         except WindowsException:
             return -1
